@@ -32,7 +32,8 @@ namespace LongoMatch.Common
 			settings.CaptureSourceType = CaptureSourceType.System;
 			settings.EncodingSettings = new EncodingSettings(VideoStandards.P480_4_3,
 			                                                 EncodingProfiles.MP4,
-			                                                 25, 1, 1000, 128, "", 20);
+			                                                 EncodingQualities.Medium,
+			                                                 25, 1, "", 20);
 			return settings;
 		}
 	}
