@@ -49,8 +49,10 @@ namespace LongoMatch.Gui
 		public event LongoMatch.Handlers.DrawFrameHandler DrawFrame;
 		public event SeekEventHandler SeekEvent;
 		public event DetachPlayerHandler Detach;
+		public event PlaybackRateChangedHandler PlaybackRateChanged;
 
 		private const int THUMBNAIL_MAX_WIDTH = 100;
+		const int SCALE_FPS = 25;
 		private LongoMatch.Video.Common.TickHandler tickHandler;
 		private LongoMatch.Multimedia.Interfaces.IPlayer player;
 		private long length=0;
@@ -63,11 +65,13 @@ namespace LongoMatch.Gui
 		private float rate=1;
 		private double previousVLevel = 1;
 		private bool muted=false;
+		bool emitRateScale = true;
 		private object[] pendingSeek=null; //{start,stop,rate}
 		//the player.mrl is diferent from the filename as it's an uri eg:file:///foo.avi
 		private string filename = null;
 		protected VolumeWindow vwin;
 		bool readyToSeek = false;
+		Seeker seeker;
 
 
 		#region Constructors
@@ -94,6 +98,8 @@ namespace LongoMatch.Gui
 			seeksQueue [0] = -1;
 			seeksQueue [1] = -1;
 			detachbutton.Clicked += (sender, e) => EmitDetach();
+			seeker = new Seeker();
+			seeker.SeekEvent += HandleSeekEvent;
 		}
 
 		#endregion
@@ -123,7 +129,7 @@ namespace LongoMatch.Gui
 				return rate;
 			}
 			set {
-				vscale1.Value = (int)(value*25);
+				SetScaleValue ((int)(value*SCALE_FPS));
 			}
 		}
 		
@@ -310,12 +316,8 @@ namespace LongoMatch.Gui
 
 		public void SeekToPreviousFrame(bool in_segment) {
 			long currentTime = player.CurrentTime;
-			if(currentTime> segmentStartTime) {
-				if(player.Playing)
-					player.Pause();
-				player.SeekToPreviousFrame(GetRateFromScale(),in_segment);
-				if(SeekEvent != null)
-					SeekEvent(currentTime);
+			if (currentTime > segmentStartTime) {
+				seeker.Seek (SeekType.StepDown, GetRateFromScale(), in_segment);
 			}
 		}
 
@@ -349,16 +351,16 @@ namespace LongoMatch.Gui
 				SeekEvent(stop);
 		}
 
-		public void SetStartStop(long start, long stop) {
+		public void SetStartStop(long start, long stop, float rate = 1) {
 			segmentStartTime = start;
 			segmentStopTime = stop;
 			closebutton.Show();
-			vscale1.Value = 25;
+			SetScaleValue ((int) (rate * SCALE_FPS));
 			if (readyToSeek) {
-				player.SegmentSeek(start, stop, GetRateFromScale());
+				player.SegmentSeek(start, stop, rate);
 				player.Play();
 			} else {
-				pendingSeek = new object[3] {start, stop, GetRateFromScale()};
+				pendingSeek = new object[3] {start, stop, rate};
 			}
 		}
 
@@ -366,7 +368,7 @@ namespace LongoMatch.Gui
 			closebutton.Hide();
 			segmentStartTime = 0;
 			segmentStopTime = 0;
-			vscale1.Value=25;
+			SetScaleValue (SCALE_FPS);
 			//timescale.Sensitive = true;
 			slength = TimeString.MSecondsToSecondsString(length);
 			SegmentClosedEvent();
@@ -387,15 +389,21 @@ namespace LongoMatch.Gui
 
 		#region Private methods
 
+		void SetScaleValue (int value) {
+			emitRateScale = false;
+			vscale1.Value = value;
+			emitRateScale = true;
+		}
+		
 		private float GetRateFromScale() {
 			VScale scale= vscale1;
 			double val = scale.Value;
 
-			if(val >25) {
-				val = val-25 ;
+			if(val >SCALE_FPS) {
+				val = val - SCALE_FPS ;
 			}
-			else if(val <=25) {
-				val = val/25;
+			else if(val <= SCALE_FPS) {
+				val = val / SCALE_FPS;
 			}
 			return (float)val;
 		}
@@ -438,13 +446,13 @@ namespace LongoMatch.Gui
 		private void SeekFromTimescale(double pos) {
 			if(InSegment()) {
 				long seekPos = segmentStartTime + (long)(pos*(segmentStopTime-segmentStartTime));
-				player.SeekInSegment(seekPos, GetRateFromScale());
-				timelabel.Text= TimeString.MSecondsToSecondsString(seekPos) + "/" +
-				                TimeString.MSecondsToSecondsString(segmentStopTime-segmentStartTime);
+				seeker.Seek (SeekType.Keyframe, GetRateFromScale(), true, seekPos);
+				timelabel.Text= TimeString.MSecondsToMSecondsString(seekPos) + "/" +
+				                TimeString.MSecondsToMSecondsString(segmentStopTime-segmentStartTime);
 			}
 			else {
-				player.Position = pos;
-				timelabel.Text= TimeString.MSecondsToSecondsString(player.CurrentTime) + "/" + slength;
+				seeker.Seek (SeekType.Keyframe, GetRateFromScale(), true, (int) (pos * length));
+				timelabel.Text= TimeString.MSecondsToMSecondsString(player.CurrentTime) + "/" + slength;
 				Rate = 1;
 			}
 		}
@@ -605,15 +613,15 @@ namespace LongoMatch.Gui
 		protected virtual void OnVscale1FormatValue(object o, Gtk.FormatValueArgs args)
 		{
 			double val = args.Value;
-			if(val >25) {
-				val = val-25 ;
+			if(val > SCALE_FPS) {
+				val = val - SCALE_FPS ;
 				args.RetVal = val +"X";
 			}
-			else if(val ==25) {
+			else if(val == SCALE_FPS) {
 				args.RetVal = "1X";
 			}
-			else if(val <25) {
-				args.RetVal = "-"+val+"/25"+"X";
+			else if(val < SCALE_FPS) {
+				args.RetVal = "-"+val+"/"+SCALE_FPS+"X";
 			}
 		}
 
@@ -637,6 +645,9 @@ namespace LongoMatch.Gui
 			else
 				player.SetRate(val);
 			rate = val;
+			if (PlaybackRateChanged != null && emitRateScale) {
+				PlaybackRateChanged (rate);
+			}
 		}
 
 		protected virtual void OnVideoboxButtonPressEvent(object o, Gtk.ButtonPressEventArgs args)
@@ -685,6 +696,27 @@ namespace LongoMatch.Gui
 			if(DrawFrame != null)
 				DrawFrame(currentTime);
 		}
+		
+		void HandleSeekEvent (SeekType type, float rate, bool inSegment, long start, long stop)
+		{
+			/* We only use it for backwards framestepping for now */
+			if (type == SeekType.StepDown || type == SeekType.StepUp) {
+				if(player.Playing)
+					player.Pause ();
+				if (type == SeekType.StepDown)
+					player.SeekToPreviousFrame (rate, inSegment);
+				else
+					player.SeekToNextFrame (rate, inSegment);
+				if (SeekEvent != null)
+					SeekEvent ((int)AccurateCurrentTime);
+			}
+			if (type == SeekType.Accurate || type == SeekType.Keyframe) {
+				player.SeekTime (start, rate, type == SeekType.Accurate);
+				if (SeekEvent != null)
+					SeekEvent ((int)start);
+			}
+		}
+
 		#endregion
 	}
 }
