@@ -24,6 +24,8 @@ using Mono.Unix;
 using LongoMatch.Video.Editor;
 using LongoMatch.Video.Common;
 using LongoMatch.Common;
+using LongoMatch.Gui.Helpers;
+using Misc = LongoMatch.Gui.Helpers.Misc;
 
 namespace LongoMatch.Gui.Dialog
 {
@@ -33,16 +35,16 @@ namespace LongoMatch.Gui.Dialog
 	public partial class VideoEditionProperties : Gtk.Dialog
 	{
 		EncodingSettings encSettings;
-		ListStore stdStore;
-		ListStore encStore;
+		ListStore stdStore, encStore, qualStore;
 
 		#region Constructors
 		public VideoEditionProperties()
 		{
 			this.Build();
 			encSettings = new EncodingSettings();
-			FillVideoStandards();
-			FillEncodingProfiles();
+			stdStore = Misc.FillImageFormat (sizecombobox, Config.RenderVideoStandard);
+			encStore = Misc.FillEncodingFormat (formatcombobox, Config.RenderEncodingProfile);
+			qualStore = Misc.FillQuality (qualitycombobox, Config.RenderEncodingQuality);
 		}
 		#endregion
 
@@ -88,50 +90,11 @@ namespace LongoMatch.Gui.Dialog
 
 		#endregion
 
-		private void FillVideoStandards() {
-			stdStore = new ListStore(typeof(string), typeof (VideoStandard));
-			stdStore.AppendValues(VideoStandards.P240_4_3.Name, VideoStandards.P240_4_3);
-			stdStore.AppendValues(VideoStandards.P240_16_9.Name, VideoStandards.P240_16_9);
-			stdStore.AppendValues(VideoStandards.P480_4_3.Name, VideoStandards.P480_4_3);
-			stdStore.AppendValues(VideoStandards.P480_16_9.Name, VideoStandards.P480_16_9);
-			stdStore.AppendValues(VideoStandards.P720_4_3.Name, VideoStandards.P720_4_3);
-			stdStore.AppendValues(VideoStandards.P720_16_9.Name, VideoStandards.P720_16_9);
-			stdStore.AppendValues(VideoStandards.P1080_4_3.Name, VideoStandards.P1080_4_3);
-			stdStore.AppendValues(VideoStandards.P1080_16_9.Name, VideoStandards.P1080_16_9);
-			sizecombobox.Model = stdStore;
-			sizecombobox.Active = 2;
-		}
-
-		private void FillEncodingProfiles() {
-			encStore = new ListStore(typeof(string), typeof (EncodingProfile));
-			encStore.AppendValues(EncodingProfiles.MP4.Name, EncodingProfiles.MP4);
-			encStore.AppendValues(EncodingProfiles.Avi.Name, EncodingProfiles.Avi);
-			encStore.AppendValues(EncodingProfiles.WebM.Name, EncodingProfiles.WebM);
-			formatcombobox.Model = encStore;
-			formatcombobox.Active = 0;
-		}
 		
 		protected virtual void OnButtonOkClicked(object sender, System.EventArgs e)
 		{
 			TreeIter iter;
 			
-			if(qualitycombobox.ActiveText == Catalog.GetString("Low")) {
-				encSettings.VideoBitrate = (uint) VideoQuality.Low;
-				encSettings.AudioBitrate = (uint) AudioQuality.Low;
-			}
-			else if(qualitycombobox.ActiveText == Catalog.GetString("Normal")) {
-				encSettings.VideoBitrate = (uint) VideoQuality.Normal;
-				encSettings.AudioBitrate =(uint)  AudioQuality.Normal;
-			}
-			else if(qualitycombobox.ActiveText == Catalog.GetString("Good")) {
-				encSettings.VideoBitrate =(uint)  VideoQuality.Good;
-				encSettings.AudioBitrate =(uint)  AudioQuality.Good;
-			}
-			else if(qualitycombobox.ActiveText == Catalog.GetString("Extra")) {
-				encSettings.VideoBitrate =(uint)  VideoQuality.Extra;
-				encSettings.AudioBitrate =(uint)  AudioQuality.Extra;
-			}
-
 			/* Get size info */
 			sizecombobox.GetActiveIter(out iter);
 			encSettings.VideoStandard = (VideoStandard) stdStore.GetValue(iter, 1);
@@ -140,11 +103,14 @@ namespace LongoMatch.Gui.Dialog
 			formatcombobox.GetActiveIter(out iter);
 			encSettings.EncodingProfile = (EncodingProfile) encStore.GetValue(iter, 1);
 			
+			/* Get quality info */
+			qualitycombobox.GetActiveIter(out iter);
+			encSettings.EncodingQuality = (EncodingQuality) qualStore.GetValue(iter, 1);
+			
 			encSettings.OutputFile = filelabel.Text;
 			
-			/* FIXME: Configure with the UI */
-			encSettings.Framerate_n = 25;
-			encSettings.Framerate_d = 1;
+			encSettings.Framerate_n = Config.FPS_N;
+			encSettings.Framerate_d = Config.FPS_D;
 			
 			encSettings.TitleSize = 20; 
 			
